@@ -31,8 +31,10 @@ class RootInstallation(Recipe):
 
         # Fill the common path pattern
         super(RootInstallation, self).__init__("root")
-        self.config['branch'] = 'v6-20-00'
+        self.config['branch'] = 'v6-20-04'
         self.config['cmake_custom_flags'] = ''
+        self.config['cmake_build_type']='RelWithDebInfo'
+
 
     def find_python(self):
         from subprocess import check_output
@@ -78,6 +80,10 @@ class RootInstallation(Recipe):
         # ROOT packets to disable in our build (go with -D{name}=ON flag)
         # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
         self.build_cmd = "cmake -Wno-dev -DCMAKE_INSTALL_PREFIX={install_path} " \
+                         " -DCMAKE_CXX_STANDARD={cxx_standard}" \
+                         " -DCMAKE_BUILD_TYPE={cmake_build_type}"\
+                         " -Dhttp=ON" \
+                         " -Droot7=ON" \
                          " -Dgdml=ON" \
                          " -Dminuit2=ON" \
                          " {python_flag}" \
